==> haskell-svg-builder-0.1.1-238-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-JVTRo1MRVnDlp8Ecyz4NW
key:                  svg-builder-0.1.1-JVTRo1MRVnDlp8Ecyz4NW
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  f2d0f545084885b152b5dcfae24e2630
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-JVTRo1MRVnDlp8Ecyz4NW
depends:
    base-4.17.2.1 blaze-builder-0.4.3-HXodF8PiFiTI0hprQuztF4
    bytestring-0.11.5.3 hashable-1.4.4.0-4IkOt4KzeSSA3Xc4u5PLaT
    text-2.0.2 unordered-containers-0.2.20-A2tjqfQXDXnFd3Ae9FP0C3

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-svg-builder-0.1.1-239-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-AuvtrDMnRrG7PwBDu1roJT
key:                  svg-builder-0.1.1-AuvtrDMnRrG7PwBDu1roJT
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  1c1be217b5523cd191bc800a2c003fdf
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-AuvtrDMnRrG7PwBDu1roJT
depends:
    base-4.17.2.1 blaze-builder-0.4.3-sOh2upotMIHSy0H3z8bmI
    bytestring-0.11.5.3 hashable-1.4.4.0-CTf4tWLvOCwE4B8hp3PoEK
    text-2.0.2 unordered-containers-0.2.20-5aRSzj1YCHv4h2N6lFa6Hx

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
